==> helmod_0.7.7.zip: helmod_0.7.7/prototypes/fonts.lua <==
data:extend(
{
  {
    type = "font",
    name = "helmod_font_default",
    from = "default",
    size = 10
  },
  {
    type = "font",
    name = "helmod_font_bold",
    from = "default-bold",
    size = 12
  },
  {
    type = "font",
    name = "helmod_font_title_frame",
    from = "default-bold",
    size = 16
  },
  
  
  
  {
    type = "font",
    name = "helmod_font_small",
    from = "default",
    size = 10
  },
  {
    type = "font",
    name = "helmod_font_medium",
    from = "default",
    size = 11
  },
  {
    type = "font",
    name = "helmod_font_normal",
    from = "default",
    size = 12
  },
  {
    type = "font",
    name = "helmod_font_big",
    from = "default",
    size = 14
  },
  {
    type = "font",
    name = "helmod_font_small_bold",
    from = "default-bold",
    size = 10
  },
  {
    type = "font",
    name = "helmod_font_small2_bold",
    from = "default-bold",
    size = 8
  },
  {
    type = "font",
    name = "helmod_font_small_bold_border",
    from = "default-bold",
    size = 10,
    border = true,
    border_color = {}
  },
  {
    type = "font",
    name = "helmod_font_icon",
    from = "default-bold",
    size = 12,
    border = true,
    border_color = {}
  },
  {
    type = "font",
    name = "helmod_font_icon_3",
    from = "default-bold",
    size = 12
  },
  {
    type = "font",
    name = "helmod_font_icon_4",
    from = "default",
    size = 12
  },
  {
    type = "font",
    name = "helmod_font_normal_bold",
    from = "default-bold",
    size = 12
  },
  {
    type = "font",
    name = "helmod_font_icon",
    from = "default-bold",
    size = 12,
    border = true,
    border_color = {}
  },
  {
    type = "font",
    name = "helmod_font_big_bold",
    from = "default-bold",
    size = 14
  }
})

==> helmod_2.2.6.zip: helmod_2.2.6/prototypes/fonts.lua <==
data:extend(
{
  {
    type = "font",
    name = "helmod_font_default",
    from = "default",
    size = 10
  },
  {
    type = "font",
    name = "helmod_font_bold",
    from = "default-bold",
    size = 12
  },
  {
    type = "font",
    name = "helmod_font_title_frame",
    from = "default-bold",
    size = 16
  },
  
  {
    type = "font",
    name = "helmod_font_header",
    from = "default-bold",
    size = 24
  },
  
  
  
  {
    type = "font",
    name = "helmod_font_small",
    from = "default",
    size = 10
  },
  {
    type = "font",
    name = "helmod_font_medium",
    from = "default",
    size = 11
  },
  {
    type = "font",
    name = "helmod_font_normal",
    from = "default",
    size = 12
  },
  {
    type = "font",
    name = "helmod_font_big",
    from = "default",
    size = 14
  },
  {
    type = "font",
    name = "helmod_font_medium_bold",
    from = "default-bold",
    size = 11
  },
  {
    type = "font",
    name = "helmod_font_medium_bold_border",
    from = "default-bold",
    size = 11,
    border = true
  },
  {
    type = "font",
    name = "helmod_font_small_bold",
    from = "default-bold",
    size = 10
  },
  {
    type = "font",
    name = "helmod_font_small_bold_border",
    from = "default-bold",
    size = 10,
    border = true,
    border_color = {}
  },
  {
    type = "font",
    name = "helmod_font_icon",
    from = "default-bold",
    size = 12,
    border = true,
    border_color = {}
  },
  {
    type = "font",
    name = "helmod_font_icon_3",
    from = "default-bold",
    size = 12
  },
  {
    type = "font",
    name = "helmod_font_icon_4",
    from = "default",
    size = 12
  },
  {
    type = "font",
    name = "helmod_font_normal_bold",
    from = "default-bold",
    size = 12
  },
  {
    type = "font",
    name = "helmod_font_icon",
    from = "default-bold",
    size = 12,
    border = true,
    border_color = {}
  },
  {
    type = "font",
    name = "helmod_font_big_bold",
    from = "default-bold",
    size = 16
  },
  {
    type = "font",
    name = "helmod_font_calculator",
    from = "default-bold",
    size = 20
  },
  {
    type = "font",
    name = "helmod_font_temperature",
    from = "default-bold",
    size = 12,
    border = true
  }
})
